#
# Spec file for prolinga-repository
#
Summary: 	XML database holding ProLinga application definitions.
Name: 		prolinga-repository
Version: 	0.0.2
Release: 	1.fc11.xobas
License: 	GPL
Group:		System Environment/Libraries
Source: 	http://download.prolinga.org/main/sources/%{name}-%{version}.tar.bz2
URL: 		http://www.xobas.com/
Vendor: 	Xobas Software
Packager: 	Bas Driessen <bas.driessen@xobas.com>
BuildRoot: 	%{_tmppath}/%{name}-%{version}-root
Requires: 	dbxml >= 2.3.10
Requires: 	libxml2 >= 2.6.5
Requires: 	prolinga-soap >= 0.0.2

%description
The ProLinga-Repository Project forms the foundation 
of the ProLinga Development and Run-Time tools. A native 
XML database, built on Berkeley DB XML, that holds 
ProLinga application definitions as XML documents which 
can be stored and managed using an API and send over 
the network using the ProLinga SOAP client library.

%package server
Summary:	Daemon binary to provide Web Service functionality.
Group:		System Environment/Libraries
Requires:	%name = %{version}
Requires: 	dbxml >= 2.3.10
Requires: 	libxml2 >= 2.6.5
Requires: 	prolinga-soap >= 0.0.2

%description server
This package contains the daemon binary that provides
access to the repository over the network.

%package devel
Summary:	Development libraries and header files for prolinga-repository.
Group:		Development/Libraries
Requires:	%name = %{version}
Requires: 	dbxml >= 2.3.10
Requires: 	dbxml-devel >= 2.3.10
Requires: 	prolinga-soap >= 0.0.2
Requires: 	prolinga-soap-devel >= 0.0.1
Requires: 	libxml2 >= 2.6.5
Requires: 	libxml2-devel >= 2.6.5

%description devel
This package contains the header files and libraries needed to write
or compile programs that use prolinga-repository.

%prep
%setup -q

%build
./bootstrap
%configure \
	--prefix=%{_prefix} \
	--libdir=%{_libdir}
make
#make html

%install
rm -rf %{buildroot}
%makeinstall

# Put startup script in the right place.
mkdir -p %{buildroot}%{_sysconfdir}/rc.d/init.d/
install -m 755 %{_builddir}/%{name}-%{version}/prolinga/prolingarepd.init %{buildroot}%{_sysconfdir}/rc.d/init.d/prolingarepd

# Set hostname to localhost in config file.
sed -e "s?`(hostname || uname -n) 2>/dev/null | sed 1q`<?localhost<?g" < %{buildroot}%{_sysconfdir}/prolingarepcfg.xml > %{_tmppath}/prolingarepcfg.tmp
mv %{_tmppath}/prolingarepcfg.tmp %{buildroot}%{_sysconfdir}/prolingarepcfg.xml

# Create temporary config file with modified repository path to create initial repository.
sed -e "s?<SystemPath>?<SystemPath>%{buildroot}?g" < %{buildroot}%{_sysconfdir}/prolingarepcfg.xml > %{_tmppath}/prolingareptmp.xml

# Set Library Path
LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
export LD_LIBRARY_PATH

# Create empty repository.
mkdir -p %{buildroot}%{_localstatedir}/lib/prolinga/system
%{buildroot}%{_bindir}/prolingarepcreate --config %{_tmppath}/prolingareptmp.xml system

# Set permissions right
chmod 777 %{buildroot}%{_localstatedir}/lib/prolinga/system
chmod 666 %{buildroot}%{_localstatedir}/lib/prolinga/system/system

# Load applications into repository.
%{buildroot}%{_bindir}/prolingarepexec --config %{_tmppath}/prolingareptmp.xml --in %{buildroot}%{_datadir}/prolinga/appn/administrator.xad --out %{_tmppath}/rcout.xml
%{buildroot}%{_bindir}/prolingarepexec --config %{_tmppath}/prolingareptmp.xml --in %{buildroot}%{_datadir}/prolinga/appn/developer.xad --out %{_tmppath}/rcout.xml
%{buildroot}%{_bindir}/prolingarepexec --config %{_tmppath}/prolingareptmp.xml --in %{buildroot}%{_datadir}/prolinga/appn/stock.xad --out %{_tmppath}/rcout.xml

# Remove cache files
rm -f %{buildroot}%{_localstatedir}/lib/prolinga/system/__*

%clean
rm -rf %{buildroot}

%post 
# update library links.
/sbin/ldconfig

# Change hostname from localhost to real hostname in config file.
sed -e "s?localhost<?`(hostname || uname -n) 2>/dev/null | sed 1q`<?g" < %{_sysconfdir}/prolingarepcfg.xml > %{_tmppath}/prolingarepcfg.tmp
mv %{_tmppath}/prolingarepcfg.tmp %{_sysconfdir}/prolingarepcfg.xml

# Set correct permissions
chmod 644 %{_sysconfdir}/prolingarepcfg.xml
chmod 755 %{_localstatedir}/lib/prolinga
chmod 777 %{_localstatedir}/lib/prolinga/system
chmod 666 %{_localstatedir}/lib/prolinga/system/system

%post server
# Add prolingarepd as service
/sbin/chkconfig --add prolingarepd

%preun server
if [ "$1" -eq 0 ]; then
    /sbin/service prolingarepd stop > /dev/null 2>&1
    /sbin/chkconfig --del prolingarepd
fi
exit 0

%postun
# update library links.
/sbin/ldconfig

%postun server
if [ "$1" -ge 1 ]; then
    /sbin/service prolingarepd condrestart > /dev/null 2>&1
fi
exit 0

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog README NEWS
%doc doc/html
%{_bindir}/prolingarepclient
%{_bindir}/prolingarepcreate
%{_bindir}/prolingarepexec
%{_libdir}/*.so.*
%{_datadir}/prolinga/appn
%{_localstatedir}/lib/prolinga/system/readme_system.txt
%{_localstatedir}/lib/prolinga/system/system
%{_sysconfdir}/prolingarepcfg.xml

%files server
%defattr(-, root, root)
%{_bindir}/prolingarepd
%config /etc/rc.d/init.d/*

%files devel
%defattr(-, root, root)
%doc doc/*.xml doc/*.xsl doc/*.txt
%{_includedir}/prolinga
%{_libdir}/*.a
%{_libdir}/*.la
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%changelog
* Wed Aug 26 2009 Bas Driessen <bas.driessen@xobas.com> 0.0.2-1.fc11
- Build for Fedora 11.
- Update to new upstream release.
- Remove XQilla library patch.
- Move repository files from datadir to localstatedir/lib.

* Tue May 20 2008 Bas Driessen <bas.driessen@xobas.com> 0.0.1-1.fc9
- Build for Fedora 9.

* Sat Mar 22 2008 Bas Driessen <bas.driessen@xobas.com> 0.0.1-1.fc8
- Initial spec file.



